@@ -27,11 +27,10 @@ from .exceptions import NoActiveContext
 from .utils import _NotSet, Terminal
 
 if TYPE_CHECKING:
-    from .core import CommandType, AnyConfig
     from .command_parameters import CommandParameters
     from .commands import Command
     from .parameters import Parameter, ActionFlag
-    from .typing import Bool, ParamOrGroup
+    from .typing import Bool, ParamOrGroup, CommandType, AnyConfig
 
 __all__ = [
     'Context',
