@@ -8,25 +8,22 @@ from __future__ import annotations
 
 from functools import partial, update_wrapper, reduce
 from operator import xor
-from typing import TYPE_CHECKING, Any, Optional, Callable, Union, Tuple
+from os import environ
+from typing import Any, Optional, Callable, Sequence, Union, Tuple
 
-from ..context import ctx
-from ..exceptions import ParameterDefinitionError, BadArgument, CommandDefinitionError, ParamUsageError
-from ..inputs import InputTypeFunc, normalize_input_type
+from ..context import ctx, ParseState
+from ..exceptions import ParameterDefinitionError, BadArgument, CommandDefinitionError, ParamUsageError, NoEnvVar
+from ..inputs import normalize_input_type
 from ..nargs import Nargs, NargsValue
-from ..utils import _NotSet, Bool
+from ..typing import Bool, T_co, ChoicesType, InputTypeFunc, CommandCls, CommandObj
+from ..utils import _NotSet
 from .base import BasicActionMixin, BaseOption, parameter_action
 from .option_strings import TriFlagOptionStrings
 
-if TYPE_CHECKING:
-    from ..core import CommandType
-    from ..commands import Command
-
 __all__ = ['Option', 'Flag', 'TriFlag', 'ActionFlag', 'Counter', 'action_flag', 'before_main', 'after_main']
-# TODO: envvar param to pull value from an env var (or tuple of vars, in order) if no value given, but env var is set?
 
 
-class Option(BasicActionMixin, BaseOption):
+class Option(BasicActionMixin, BaseOption[T_co]):
     """
     A generic option that can be specified as ``--foo bar`` or by using other similar forms.
 
@@ -46,9 +43,18 @@ class Option(BasicActionMixin, BaseOption):
       on every value for this parameter to transform the value.  By default, no transformation is performed, and
       values will be strings.  If not specified, but a type annotation is detected, then that annotation will be
       used as if it was provided here.  When both are present, this argument takes precedence.
+    :param choices: A container that holds the specific values that users must pick from.  By default, any value is
+      allowed.
+    :param env_var: A string or sequence (tuple, list, etc) of strings representing environment variables that should
+      be searched for a value when no value was provided via CLI.  If a value was provided via CLI, then these variables
+      will not be checked.  If multiple env variable names/keys were provided, then they will be checked in the order
+      that they were provided.  When enabled, values from env variables take precedence over the default value.  When
+      enabled and the Parameter is required, then either a CLI value or an env var value must be provided.
     :param kwargs: Additional keyword arguments to pass to :class:`.BaseOption`.
     """
 
+    env_var: Union[str, Sequence[str]] = None
+
     def __init__(
         self,
         *option_strs: str,
@@ -57,6 +63,8 @@ class Option(BasicActionMixin, BaseOption):
         default: Any = _NotSet,
         required: Bool = False,
         type: InputTypeFunc = None,  # noqa
+        choices: ChoicesType = None,
+        env_var: Union[str, Sequence[str]] = None,
         **kwargs,
     ):
         if nargs is not None:
@@ -68,9 +76,31 @@ class Option(BasicActionMixin, BaseOption):
         elif action == 'store' and self.nargs != 1:
             raise ParameterDefinitionError(f'Invalid nargs={self.nargs} for action={action!r}')
         super().__init__(*option_strs, action=action, default=default, required=required, **kwargs)
-        self.type = normalize_input_type(type, self.choices)
-        if action == 'append':
-            self._init_value_factory = list
+        self.type = normalize_input_type(type, choices)
+        if env_var:
+            self.env_var = env_var
+
+    def _from_env(self) -> T_co:
+        env_var = self.env_var
+        if not env_var:
+            raise NoEnvVar(self)
+
+        env_vars = (env_var,) if isinstance(env_var, str) else env_var
+        for env_var in env_vars:
+            try:
+                value = environ[env_var]
+            except KeyError:
+                pass
+            else:
+                return self.prepare_and_validate(value)
+
+        raise NoEnvVar(self)
+
+    def _set_from_env(self):
+        value = self._from_env()
+        ctx.record_action(self)
+        action_method = getattr(self, self.action)
+        return action_method(value)
 
 
 # TODO: 1/2 flag, 1/2 option, like Counter, but for any value
@@ -85,13 +115,11 @@ class _Flag(BaseOption):
         cls._use_opt_str = use_opt_str
 
     def __init__(self, *option_strs: str, **kwargs):
-        bad = ', '.join(repr(key) for key in ('choices', 'metavar') if key in kwargs)
-        if bad:
-            art, s = ('', 's') if ',' in bad else ('an ', '')
-            raise TypeError(f'{self.__class__.__name__}.__init__() got {art}unexpected keyword argument{s}: {bad}')
+        if 'metavar' in kwargs:
+            raise TypeError(f"{self.__class__.__name__}.__init__() got an unexpected keyword argument: 'metavar'")
         super().__init__(*option_strs, **kwargs)
 
-    def _init_value_factory(self):  # pylint: disable=W0221
+    def _init_value_factory(self, state: ParseState):
         if self.action == 'store_const':
             return self.default
         else:
@@ -208,7 +236,7 @@ class TriFlag(_Flag, accepts_values=False, accepts_none=True, use_opt_str=True):
         self.consts = consts
         self.option_strs.add_alts(alt_prefix, alt_long, alt_short)
 
-    def __set_name__(self, command: CommandType, name: str):
+    def __set_name__(self, command: CommandCls, name: str):
         super().__set_name__(command, name)
         self.option_strs.update_alts(self, command, name)
 
@@ -302,7 +330,7 @@ class ActionFlag(Flag, repr_attrs=('order', 'before_main')):
         self.func = func
         return self
 
-    def __get__(self, command: Optional[Command], owner: CommandType) -> Union[ActionFlag, Callable]:
+    def __get__(self, command: Optional[CommandObj], owner: CommandCls) -> Union[ActionFlag, Callable]:
         # Allow the method to be called, regardless of whether it was specified
         if command is None:
             return self
@@ -351,8 +379,6 @@ class Counter(BaseOption, accepts_values=True, accepts_none=True):
     nargs = Nargs('?')
 
     def __init__(self, *option_strs: str, action: str = 'append', default: int = 0, const: int = 1, **kwargs):
-        if 'choices' in kwargs:
-            raise TypeError(f"{self.__class__.__name__}.__init__() got an unexpected keyword argument 'choices'")
         vals = {'const': const, 'default': default}
         bad_types = ', '.join(f'{k}={v!r}' for k, v in vals.items() if not isinstance(v, self.type))
         if bad_types:
@@ -360,7 +386,7 @@ class Counter(BaseOption, accepts_values=True, accepts_none=True):
         super().__init__(*option_strs, action=action, default=default, **kwargs)
         self.const = const
 
-    def _init_value_factory(self):  # pylint: disable=W0221
+    def _init_value_factory(self, state: ParseState):
         return self.default
 
     def prepare_value(self, value: Optional[str], short_combo: bool = False, pre_action: bool = False) -> int:
